---
title: "Remove Tools"
description: "You can exclude default tools:"
icon: "minus"
mode: "wide"
---


```python
from openbrowser import Tools

tools = Tools(exclude_actions=['search', 'wait'])
agent = Agent(task='...', llm=llm, tools=tools)
```
